# DFS数据模型

## 0级数据

| 列名           | 类型                      | 说明          |
|------------|-------------------------|-------------------|
| level0_id    | str          | 0级数据的ID                  |
| project_id   | str          | Project的ID                 |
| obs_id       | str          | 观测的ID                     |
| detector_no  | str          | 探测器的编号                  |
| file_type    | str          | 观测文件的类型                |
| module_id    | str          | 模块的ID                     |
| filter       | str          | 滤光片                       |
| obs_time     | datetime     | 观测时间                     |
| exp_start    | float        | 曝光开始时间）                |
| exp_time     | float        | 曝光时间                     |
| file_name    | str          | 文件名                      |
| file_path    | str          | 文件路径                     |
| file_size    | int          | 文件大小（以字节为单位）       |
| qc0_status   | int          | QC0状态                     |
| qc0_time     | datetime     | QC0时间                     |
| prc_status   | int          | 处理状态，默认为-1024未处理   |
| prc_time     | datetime     | 处理时间                    |
| dataset      | str          | 数据集标识                   |
| create_time  | datetime     | 创建时间                     |

**附加的头部信息**：('RA_OBJ', 'DEC_OBJ', 'CRPIX1', 'CRPIX2', 'CRVAL1', 'CRVAL2', 'CTYPE1', 'CTYPE2', 'CD1_1', 'CD1_2', 'CD2_1', 'CD2_2', 'FILTER', 'OBJECT')

## 0级数据处理记录

| 列名           | 类型                      | 说明         |
|------------|-------------------------|----------------------|
| level0_id    | str          | 0级数据的ID               |
| dag_id  | str          | 流水线的ID               |
| dag_run_id       | str          | run ID                  |
| batch_id     | str          | 批次ID     |
| dataset      | str          | 数据集标识                    |
| prc_status   | int          | 处理状态                  |
| prc_time     | datetime     | 处理时间                  |
| prc_module   | str          | 处理模块                  |
| message      | str          | 消息                     |

## 1级数据

| 列名            | 类型                      | 说明           |
|-------------|-------------------------|---------------------|
| project_id    | str         | 项目ID                      |
| level0_id     | str         | 0级数据ID                     |
| level1_id     | str         | 1级数据ID                    |
| obs_id        | str         | 观测ID                       |
| detector_no   | str         | 探测器编号                    |
| data_type     | str         | 数据类型                      |
| module_id     | str         | 模块ID                       |
| filter        | str         | 滤光片                        |
| obs_time      | datetime    | 观测时间                      |
| file_name     | str         | 文件名称                       |
| file_path     | str         | 文件路径                      |
| file_size     | int         | 文件大小                    |
| qc1_status    | int         | QC1状态，默认为0             |
| qc1_time      | datetime    | QC1的时间                  |
| prc_status    | int         | 处理状态，默认为-1024未处理   |
| prc_time      | datetime    | 处理时间                    |
| dag_id   | str         | 处理管线ID                  |
| pmapname      | str         | ccds pmap的名称             |
| build         | int         | 构建版本编号                 |
| dag_run_id        | str         | 运行ID                      |
| batch_id      | str         | 运行批次ID            |
| dataset       | str         | 数据集标识                   |
| create_time   | datetime    | 创建时间                     |

**附加的头部信息**：

这里按模块区分，每个模块有其对应的头部信息：

'MSC': ('FILTER','RA_OBJ','DEC_OBJ','V_WCS','T_WCS','S_WCS','WCSAXE','CTYPE1','CTYPE2','CUNIT1','CUNIT2','CRVAL1','CRVAL2','CRPIX1','CRPIX2','CD1_1','CD1_2','CD2_1','CD2_2','PV1_0','PV1_1','PV1_2','PV1_3','PV1_4','PV1_5','PV1_6','PV1_7','PV1_8','PV1_9','PV1_10','PV1_11','PV1_12','PV1_13','PV1_14','PV1_15','PV1_16','PV1_17','PV1_18','PV1_19','PV1_20','PV1_21','PV1_22','PV1_23','PV2_0','PV2_1','PV2_2','PV2_3','PV2_4','PV2_5','PV2_6','PV2_7','PV2_8','PV2_9','PV2_10','PV2_11','PV2_12','PV2_13','PV2_14','PV2_15','PV2_16','PV2_17','PV2_18','PV2_19','PV2_20','PV2_21','PV2_22','PV2_23','RA_CEN','DEC_CEN','ASTRMED1','ASTRMED2','ASTRRMS1','ASTRRMS2','NS_WCS','EQUINOX','NAXIS','NAXIS1','NAXIS2','RADECSYS','MIN_RA','MAX_RA','MIN_DEC','MAX_DEC','BRICK_ID')

'IFS': ('RA_OBJ', 'DEC_OBJ', 'OBJECT', 'RSS_VER', 'PROCESS','DATE_PROC', 'OBJ_ID', 'CUBE_VER', 'WCS_VER', 'FILE_VER', 'CTYPE3', 'NEXP', 'EXP_TIME'),

'MCI': ('RA_OBJ', 'DEC_OBJ', 'OBJECT'),

'CPIC': ('RA_OBJ', 'DEC_OBJ', 'OBJECT'),

'HSTDM': ('RA_OBJ', 'DEC_OBJ', 'OBJECT')

## 1级数据处理记录

| 列名           | 类型                 | 说明            |
|------------|-------------------------|----------------|
| level1_id    | str          | 1级数据的ID              |
| dag_id  | str          | 流水线的ID               |
| dag_run_id       | str          | run的ID                 |
| dataset      | str          | 数据集                   |
| batch_id     | str          | 批次ID                  |
| prc_status   | int          | 处理状态                 |
| prc_time     | datetime     | 处理时间                 |
| prc_module   | str          | 处理模块                 |
| message      | str          | 消息                    |

## 2级数据

| 列名            | 类型                      | 说明 |
|-------------|-------------------------|--------------------|
| project_id    | str         | 项目ID                        |
| level0_id     | str         | 0级数据ID                      |
| level1_id     | str         | 1级数据ID                     |
| level2_id     | str         | 2级数据ID                     |
| brick_id      | int         | 天区ID                       |
| obs_id        | str         | 观测ID                       |
| detector_no   | str         | 探测器编号                    |
| data_type     | str         | 数据的类型                    |
| module_id     | str         | 模块ID                       |
| filter        | str         | 滤光片                        |
| obs_time      | datetime    | 观测时间                       |
| file_name     | str         | 文件的名称                     |
| file_path     | str         | 文件在文件系统中的路径           |
| file_size     | int         | 文件的大小（以字节为单位）        |
| qc2_status    | int         | QC2状态，默认为0                |
| qc2_time      | datetime    | QC2时间                        |
| prc_status    | int         | 处理状态，默认为-1024           |
| prc_time      | datetime    | 数据处理时间                    |
| dag_id   | str         | 处理管道ID                      |
| build         | int         | 软件构建版本的编号               |
| dag_run_id        | str         | 运行ID                         |
| dataset       | str         | 数据集标识                      |
| batch_id      | str         | 批次ID                         |
| create_time   | datetime    | 创建的时间                      |

**注释**：
暂无其他信息


- [接口](./usage.md)
